<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Travellable
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function travellable_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	$classes[] = travellable_sidebar_layout();

	if ( get_theme_mod( 'travellable_enable_top_bar', true ) ) {
		$classes[] = 'topbar-active';
	}

	return $classes;
}
add_filter( 'body_class', 'travellable_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function travellable_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'travellable_pingback_header' );


/**
 * Get all posts for customizer Post content type.
 */
function travellable_get_post_choices() {
	$choices = array( '' => esc_html__( '--Select--', 'travellable' ) );
	$args    = array( 'numberposts' => -1 );
	$posts   = get_posts( $args );

	foreach ( $posts as $post ) {
		$id             = $post->ID;
		$title          = $post->post_title;
		$choices[ $id ] = $title;
	}

	return $choices;
}

/**
 * Get all pages for customizer Page content type.
 */
function travellable_get_page_choices() {
	$choices = array( '' => esc_html__( '--Select--', 'travellable' ) );
	$pages   = get_pages();

	foreach ( $pages as $page ) {
		$choices[ $page->ID ] = $page->post_title;
	}

	return $choices;
}

/**
 * Get all trips for customizer Trip content type.
 */
function travellable_get_trip_choices() {
	$choices = array( '' => esc_html__( '--Select--', 'travellable' ) );
	$posts   = get_posts(
		array(
			'post_type'   => 'itineraries',
			'numberposts' => -1,
		)
	);
	foreach ( $posts as $post ) {
		$choices[ $post->ID ] = $post->post_title;
	}
	return $choices;
}

/**
 * Get list for Popular Destination content type choices
 */
function travellable_get_popular_destination_content_type_choices() {
	$popular_destination_choices = array(
		'page' => esc_html__( 'Page', 'travellable' ),
		'post' => esc_html__( 'Post', 'travellable' ),
	);

	if ( class_exists( 'WP_Travel' ) ) {
		$popular_destination_choices = array_merge(
			$popular_destination_choices,
			array(
				'itineraries' => esc_html__( 'Trip', 'travellable' ),
			)
		);
	}

	return $popular_destination_choices;
}

/**
 * Get list for Trending Package content type choices
 */
function travellable_get_trending_package_content_type_choices() {
	$trending_package_choices = array(
		'page' => esc_html__( 'Page', 'travellable' ),
		'post' => esc_html__( 'Post', 'travellable' ),
	);

	if ( class_exists( 'WP_Travel' ) ) {
		$trending_package_choices = array_merge(
			$trending_package_choices,
			array(
				'itineraries' => esc_html__( 'Trip', 'travellable' ),
			)
		);
	}

	return $trending_package_choices;
}

/**
 * Get all taxonomy terms for customizer Destination content type.
 */
function travellable_get_taxonomy_term_choices( $taxonomy ) {
	$choices    = array( '' => esc_html__( '--Select--', 'travellable' ) );
	$tax_args   = array(
		'hide_empty' => false,
		'taxonomy'   => $taxonomy,
	);
	$taxonomies = get_categories( $tax_args );

	foreach ( $taxonomies as $cat ) {
		$choices[ $cat->term_id ] = $cat->name;
	}

	return $choices;
}

if ( ! function_exists( 'travellable_excerpt_length' ) ) :
	/**
	 * Excerpt length.
	 */
	function travellable_excerpt_length( $length ) {
		if ( is_admin() ) {
			return $length;
		}

		return get_theme_mod( 'travellable_excerpt_length', 20 );
	}
endif;
add_filter( 'excerpt_length', 'travellable_excerpt_length', 999 );

if ( ! function_exists( 'travellable_excerpt_more' ) ) :
	/**
	 * Excerpt more.
	 */
	function travellable_excerpt_more( $more ) {
		if ( is_admin() ) {
			return $more;
		}

		return '&hellip;';
	}
endif;
add_filter( 'excerpt_more', 'travellable_excerpt_more' );

if ( ! function_exists( 'travellable_sidebar_layout' ) ) {
	/**
	 * Get sidebar layout.
	 */
	function travellable_sidebar_layout() {
		$sidebar_position      = get_theme_mod( 'travellable_sidebar_position', 'right-sidebar' );
		$sidebar_position_post = get_theme_mod( 'travellable_post_sidebar_position', 'right-sidebar' );
		$sidebar_position_page = get_theme_mod( 'travellable_page_sidebar_position', 'right-sidebar' );

		if ( is_single() ) {
			$sidebar_position = $sidebar_position_post;
		} elseif ( is_page() ) {
			$sidebar_position = $sidebar_position_page;
		}

		return $sidebar_position;
	}
}

if ( ! function_exists( 'travellable_is_sidebar_enabled' ) ) {
	/**
	 * Check if sidebar is enabled.
	 */
	function travellable_is_sidebar_enabled() {
		$sidebar_position      = get_theme_mod( 'travellable_sidebar_position', 'right-sidebar' );
		$sidebar_position_post = get_theme_mod( 'travellable_post_sidebar_position', 'right-sidebar' );
		$sidebar_position_page = get_theme_mod( 'travellable_page_sidebar_position', 'right-sidebar' );

		$sidebar_enabled = true;
		if ( is_home() || is_archive() || is_search() ) {
			if ( 'no-sidebar' === $sidebar_position ) {
				$sidebar_enabled = false;
			}
		} elseif ( is_single() ) {
			if ( 'no-sidebar' === $sidebar_position || 'no-sidebar' === $sidebar_position_post ) {
				$sidebar_enabled = false;
			}
		} elseif ( is_page() ) {
			if ( 'no-sidebar' === $sidebar_position || 'no-sidebar' === $sidebar_position_page ) {
				$sidebar_enabled = false;
			}
		}
		return $sidebar_enabled;
	}
}

if ( ! function_exists( 'travellable_get_homepage_sections ' ) ) {
	/**
	 * Returns homepage sections.
	 */
	function travellable_get_homepage_sections( $homepage_layout = '' ) {
		if ( empty( $homepage_layout ) ) {
			$homepage_layout = get_theme_mod( 'travellable_homepage_layout', 'main' );
		}
		$sections = array(
			'banner'              => esc_html__( 'Banner Section', 'travellable' ),
			'trip-search'         => esc_html__( 'Trip Search', 'travellable' ),
			'about'               => esc_html__( 'About Section', 'travellable' ),
			'trending-package'    => esc_html__( 'Trending Package', 'travellable' ),
			'popular-destination' => esc_html__( 'Destination Section', 'travellable' ),
			'counter'             => esc_html__( 'Counter Section', 'travellable' ),
			'blog'                => esc_html__( 'Blog Section', 'travellable' ),
			'newsletter'          => esc_html__( 'Newsletter Section', 'travellable' ),
		);
		return $sections;
	}
}

if ( ! function_exists( 'travellable_get_default_color' ) ) {
	/**
	 * Returns default colors.
	 */
	function travellable_get_default_color() {
		$color['primary']   = '#0b3b57';
		$color['secondary'] = '#ffd930';
		return $color;
	}
}

function travellable_section_link( $section_id ) {
	$section_name      = str_replace( 'travellable_', ' ', $section_id );
	$section_name      = str_replace( '_', ' ', $section_name );
	$starting_notation = '#';
	?>
	<span class="section-link">
		<span class="section-link-title"><?php echo esc_html( $section_name ); ?></span>
	</span>
	<style type="text/css">
		<?php echo $starting_notation . $section_id; ?>:hover .section-link {
			visibility: visible;
		}
	</style>
	<?php
}

function travellable_section_link_css() {
	if ( is_customize_preview() ) {
		?>
		<style type="text/css">
			.section-link {
				visibility: hidden;
				background-color: black;
				position: relative;
				top: 80px;
				z-index: 99;
				left: 40px;
				color: #fff;
				text-align: center;
				font-size: 20px;
				border-radius: 10px;
				padding: 20px 10px;
				text-transform: capitalize;
			}
			.section-link-title {
				padding: 0 10px;
			}
		</style>
		<?php
	}
}
add_action( 'wp_head', 'travellable_section_link_css' );

/**
 * Breadcrumb.
 */
function travellable_breadcrumb( $args = array() ) {
	if ( ! get_theme_mod( 'travellable_enable_breadcrumb', true ) ) {
		return;
	}

	$args = array(
		'show_on_front' => false,
		'show_title'    => true,
		'show_browse'   => false,
	);
	breadcrumb_trail( $args );
}
add_action( 'travellable_breadcrumb', 'travellable_breadcrumb', 10 );

/**
 * Add separator for breadcrumb trail.
 */
function travellable_breadcrumb_trail_print_styles() {
	$breadcrumb_separator = get_theme_mod( 'travellable_breadcrumb_separator', '/' );

	$style = '
		.trail-items li::after {
			content: "' . esc_attr( $breadcrumb_separator ) . '";
		}';

	$style = apply_filters( 'travellable_breadcrumb_trail_inline_style', trim( str_replace( array( "\r", "\n", "\t", '  ' ), '', $style ) ) );

	if ( $style ) {
		echo "\n" . '<style type="text/css" id="breadcrumb-trail-css">' . $style . '</style>' . "\n";
	}
}
add_action( 'wp_head', 'travellable_breadcrumb_trail_print_styles' );

/**
 * Pagination for archive.
 */
function travellable_render_posts_pagination() {
	$is_pagination_enabled = get_theme_mod( 'travellable_enable_pagination', true );
	if ( $is_pagination_enabled ) {
		$pagination_type = get_theme_mod( 'travellable_pagination_type', 'default' );
		if ( 'default' === $pagination_type ) :
			the_posts_navigation();
		else :
			the_posts_pagination();
		endif;
	}
}
add_action( 'travellable_posts_pagination', 'travellable_render_posts_pagination', 10 );

/**
 * Pagination for single post.
 */
function travellable_render_post_navigation() {
	the_post_navigation(
		array(
			'prev_text' => '<span>&#10229;</span> <span class="nav-title">%title</span>',
			'next_text' => '<span class="nav-title">%title</span> <span>&#10230;</span>',
		)
	);
}
add_action( 'travellable_post_navigation', 'travellable_render_post_navigation' );

/**
 * Adds footer copyright text.
 */
function travellable_output_footer_copyright_content() {
	$theme_data = wp_get_theme();
	$search     = array( '[the-year]', '[site-link]' );
	$replace    = array( date( 'Y' ), '<a href="' . esc_url( home_url( '/' ) ) . '">' . esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );
	/* translators: 1: Year, 2: Site Title with home URL. */
	$copyright_default = sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'travellable' ), '[the-year]', '[site-link]' );
	$copyright_text    = get_theme_mod( 'travellable_footer_copyright_text', $copyright_default );
	$copyright_text    = str_replace( $search, $replace, $copyright_text );
	$copyright_text   .= esc_html( ' | ' . $theme_data->get( 'Name' ) ) . '&nbsp;' . esc_html__( 'by', 'travellable' ) . '&nbsp;<a target="_blank" href="' . esc_url( $theme_data->get( 'AuthorURI' ) ) . '">' . esc_html( ucwords( $theme_data->get( 'Author' ) ) ) . '</a>';
	/* translators: %s: WordPress.org URL */
	$copyright_text .= sprintf( esc_html__( ' | Powered by %s', 'travellable' ), '<a href="' . esc_url( __( 'https://wordpress.org/', 'travellable' ) ) . '" target="_blank">WordPress</a>. ' );
	?>
	<div class="copyright">
		<span><?php echo wp_kses_post( $copyright_text ); ?></span>
	</div>
	<?php
}
add_action( 'travellable_footer_copyright', 'travellable_output_footer_copyright_content' );
